#

##

##

##

    	genome

    	summary

    		genetics:genome:gene:sequence::blockchain:aggregate:block:tx
    			# monkey bars

    	structure

    		len ("00000000000000000000000000000001")

    		node:genetics:
    			DB:"genome 00000000000000000000000000000001":
    				collection: map [{
    					"genes": [ "1", "8" ]
    				}]
    				collection: mottos [{

    				}]
    				collection: voters [{
    					"address": "",
    				}]
    				collection: escrow

    			DB:"genome 0000000000000002":
    				collection: map [{
    					"genes": [ "1", "8" ]
    				}]
    				collection: mottos [{

    				}]
    				collection: voters
    				collection: escrow

    			DB: "genes 1":
    				collection: "gene 1" [{

    				},{

    				},{

    				}]
    				collection: "gene 2"
    				collection: "gene 3"
    				collection: "gene 4"
    				collection: "gene 5"
    				collection: "gene 6"
    				collection: "gene 7"
    				collection: "gene 8"

    			DB: "genes 2":
    				collection: "gene 9"
    				collection: "gene 10"
    				collection: "gene 11"
    				collection: "gene 13"
    				collection: "gene 14"
    				collection: "gene 15"
    				collection: "gene 16"
    				collection: "gene 17"

    	important

    		diploid cells contain the full genome.